@@ -4,7 +4,6 @@ import os
 import pprint
 import re
 import urllib.parse
-import warnings
 from collections import defaultdict
 from concurrent.futures import ThreadPoolExecutor
 from copy import deepcopy
@@ -13,7 +12,7 @@ from io import BytesIO
 from pathlib import Path
 from shutil import copyfileobj
 from threading import BoundedSemaphore
-from typing import Optional, List, Iterable, Union, Tuple, Any, TYPE_CHECKING
+from typing import Optional, List, Iterable, Union, Tuple, Dict, Any, TYPE_CHECKING
 from urllib.parse import urlparse
 
 import numpy as np
@@ -674,21 +673,25 @@ class GraphQLClient(object):
         resp.raise_for_status()
         return resp.json()
 
-    def create_dataset(self, input_params, ds_id=None):
+    def create_dataset(self, input_params, perform_enrichment=False, ds_id=None):
         query = """
-            mutation createDataset($id: String, $input: DatasetCreateInput!, $priority: Int, $useLithops: Boolean) {
+            mutation createDataset($id: String, $input: DatasetCreateInput!,
+                $priority: Int, $useLithops: Boolean, $performEnrichment: Boolean) {
                 createDataset(
                   id: $id,
                   input: $input,
                   priority: $priority,
                   useLithops: $useLithops,
+                  performEnrichment: $performEnrichment,
                 )
             }
         """
         variables = {
             'id': ds_id,
             'input': input_params,
+            'priority': 0,
             'useLithops': True,
+            'performEnrichment': perform_enrichment,
         }
         return self.query(query, variables)['createDataset']
 
@@ -707,21 +710,25 @@ class GraphQLClient(object):
     def update_dataset(
         self,
         ds_id,
-        input=None,
+        input={},
         reprocess=False,
         force=False,
+        perform_enrichment=False,
         priority=1,
     ):
         query = """
-            mutation updateMetadataDatabases($id: String!, $reprocess: Boolean,
-                $input: DatasetUpdateInput!, $priority: Int, $force: Boolean) {
-                    updateDataset(
-                      id: $id,
-                      input: $input,
-                      priority: $priority,
-                      reprocess: $reprocess,
-                      force: $force
-                    )
+            mutation updateDataset($id: String!, $input: DatasetUpdateInput!,
+                $priority: Int, $reprocess: Boolean, $force: Boolean,
+                $useLithops: Boolean, $performEnrichment: Boolean) {
+                updateDataset(
+                    id: $id,
+                    input: $input,
+                    priority: $priority,
+                    reprocess: $reprocess,
+                    force: $force,
+                    useLithops: $useLithops,
+                    performEnrichment: $performEnrichment,
+                )
             }
         """
 
@@ -731,6 +738,8 @@ class GraphQLClient(object):
             'priority': priority,
             'reprocess': reprocess,
             'force': force,
+            'useLithops': True,
+            'performEnrichment': perform_enrichment,
         }
 
         self.query(query, variables)
@@ -1099,6 +1108,16 @@ class SMDataset(object):
         is not associated with any group"""
         return (self._info['principalInvestigator'] or {}).get('name')
 
+    @property
+    def image_size(self):
+        """Image size in pixels along the X, Y axes if this data exists otherwise an empty dict"""
+        shape = {}
+        if self._info['acquisitionGeometry'] != 'null':
+            acquisition_grid = json.loads(self._info['acquisitionGeometry'])['acquisition_grid']
+            shape['x'] = acquisition_grid['count_x']
+            shape['y'] = acquisition_grid['count_y']
+        return shape
+
     @property
     def _baseurl(self):
         return self._gqclient.host
@@ -1733,6 +1752,7 @@ class SMInstance(object):
         analysis_version: Optional[int] = None,
         input_path: Optional[str] = None,
         description: Optional[str] = None,
+        perform_enrichment: Optional[bool] = False,
     ) -> str:
         """Submit a dataset for processing in METASPACE.
 
@@ -1760,8 +1780,9 @@ class SMInstance(object):
         :param analysis_version:
         :param input_path: To clone an existing dataset, specify input_path using the value of the
             existing dataset's "s3dir".
-            When input_path is suppled, imzml_fn and ibd_fn can be set to none None.
+            When input_path is suppled, imzml_fn and ibd_fn can be set to None.
         :param description: Optional text to describe the dataset
+        :param perform_enrichment: Optional enable LION for dataset.
 
         :return: The newly created dataset ID
 
@@ -1818,7 +1839,8 @@ class SMInstance(object):
                 'groupId': primary_group_id,
                 'projectIds': project_ids,
                 'isPublic': is_public,
-            }
+            },
+            perform_enrichment=perform_enrichment,
         )
         return json.loads(graphql_response)['datasetId']
 
@@ -1845,6 +1867,7 @@ class SMInstance(object):
         analysis_version: Optional[int] = None,
         reprocess: Optional[bool] = None,
         force: bool = False,
+        perform_enrichment: Optional[bool] = False,
     ):
         """Updates a dataset's metadata and/or processing settings. Only specify the fields that
         should change. All arguments should be specified as keyword arguments,
@@ -1880,6 +1903,7 @@ class SMInstance(object):
         :param force:
             True: Allow changes to datasets that are already being processed. This should be used
             with caution, as it can cause errors or inconsistent results.
+        :param perform_enrichment: Optional enable LION for dataset.
         """
 
         input_field = {}
@@ -1911,10 +1935,12 @@ class SMInstance(object):
             input_field['analysisVersion'] = analysis_version
 
         try:
-            self._gqclient.update_dataset(id, input_field, reprocess or False, force)
+            self._gqclient.update_dataset(
+                id, input_field, reprocess or False, force, perform_enrichment
+            )
         except GraphQLException as ex:
             if ex.type == 'reprocessing_needed' and reprocess is None:
-                self._gqclient.update_dataset(id, input_field, True, force)
+                self._gqclient.update_dataset(id, input_field, True, force, perform_enrichment)
             else:
                 raise
 
